/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2008 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

\*---------------------------------------------------------------------------*/

#include "phaseChangeTwoPhaseMixture.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
    defineTypeNameAndDebug(phaseChangeTwoPhaseMixture, 0);
    defineRunTimeSelectionTable(phaseChangeTwoPhaseMixture, components);
}

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::phaseChangeTwoPhaseMixture::phaseChangeTwoPhaseMixture
(
    const word& type,
    const volVectorField& U,
    const surfaceScalarField& phi,
    const word& alpha1Name
)
:
    twoPhaseMixture(U, phi, alpha1Name),
    phaseChangeTwoPhaseMixtureCoeffs_(subDict(type + "Coeffs")),
    pSat_(dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("pSat")),
    rampN_
    (
        readLabel(dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("rampN"))
    ),
    startN_
    (
        readLabel( dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("startN"))
    ),
    isRestart_
    (
         dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("restart")
     ),
    curTimeIndex_(0)
{}


// * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * * //

void Foam::phaseChangeTwoPhaseMixture::correct()
{
    qt = 1;
    if ( !isRestart_ )
    {
        if (!rampN_) rampN_ = 1;

        qt = 1.0*(++curTimeIndex_ - startN_)/rampN_;

        if (qt > 0)
        {
            if (qt > 1)
            {
               qt = 1;    
	    }
        }
        else
        {
            qt = 0;
        }
    }

    //Info << "qt = " << qt << " Restart: " << isRestart_<< " CurTim= " << curTimeIndex_ << " startN= " << startN_ << endl;
    Foam::twoPhaseMixture::correct();
}  

Foam::Pair<Foam::tmp<Foam::volScalarField> >
//Foam::phaseChangeTwoPhaseMixture::vDotAlphal() const
Foam::phaseChangeTwoPhaseMixture::vDotAlphal()
{
  //Info << "Foam::phaseChangeTwoPhaseMixture::vDotAlphal()" << endl;
    volScalarField alphalCoeff = 1.0/rho1() - alpha1_*(1.0/rho1() - 1.0/rho2());
    Pair<tmp<volScalarField> > mDotAlphal = this->mDotAlphal();

    alphalCoeff *= qt;
    
    return Pair<tmp<volScalarField> >
    (
        alphalCoeff*mDotAlphal[0],
        alphalCoeff*mDotAlphal[1]
    );
}

Foam::Pair<Foam::tmp<Foam::volScalarField> >
//Foam::phaseChangeTwoPhaseMixture::vDotP() const
Foam::phaseChangeTwoPhaseMixture::vDotP()
{
  //Info << "Foam::phaseChangeTwoPhaseMixture::vDotP()" << endl;
 
    dimensionedScalar pCoeff(1.0/rho1() - 1.0/rho2());
    Pair<tmp<volScalarField> > mDotP = this->mDotP();

    pCoeff *= qt;
    //Info << "qt = " << qt << " Restart: " << isRestart_<< " CurTim= " << curTimeIndex_ << " startN= " << startN_ << endl;
 
    return Pair<tmp<volScalarField> >(pCoeff*mDotP[0], pCoeff*mDotP[1]);
}


bool Foam::phaseChangeTwoPhaseMixture::read()
{
    if (twoPhaseMixture::read())
    {
        phaseChangeTwoPhaseMixtureCoeffs_ = subDict(type() + "Coeffs");
        lookup("pSat") >> pSat_;
        dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("pSat") >> pSat_;
        readLabel(dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("rampN")) >> rampN_;
        readLabel( dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("startN")) >> startN_;
        dictionary(phaseChangeTwoPhaseMixtureCoeffs_.subDict("cavitation")).lookup("restart") >> isRestart_;
        return true;
    }
    else
    {
        return false;
    }
}


// ************************************************************************* //
